========
pyregion
========

pyregion is a python module to parse ds9 region files. It also supports
ciao region files.


+----------------------------------------+----------------------------------------+
| ds9                                    | pyregion + matplotlib                  |
+========================================+========================================+
| .. image::    _static/region_ds9.jpg   | .. image::    _static/region_mpl.png   |
|   :width: 300px                        |   :width: 300px                        |
|   :target:    static/region_ds9.jpg    |   :target:    static/region_mpl.png    |
+----------------------------------------+----------------------------------------+


Documentation
=============

.. toctree::
   :maxdepth: 1

   users/index.rst
   examples.rst


.. note::
  *pyregion* is rather slow, likely due to a inefficient
  parser. Any contribution will be welcomed.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
